sdv.constraints.FixedCombinations
=================================

.. currentmodule:: sdv.constraints

.. autoclass:: FixedCombinations

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FixedCombinations.__init__
      ~FixedCombinations.filter_valid
      ~FixedCombinations.fit
      ~FixedCombinations.fit_transform
      ~FixedCombinations.from_dict
      ~FixedCombinations.is_valid
      ~FixedCombinations.reverse_transform
      ~FixedCombinations.to_dict
      ~FixedCombinations.transform
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FixedCombinations.constraint_columns
   
   